"{ Package: 'stx:goodies/monticello' }"

MCMczWriter subclass:#MCStxMczWriter
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'SCM-Monticello-St/X Storing'
!

!MCStxMczWriter class methodsFor:'documentation'!

documentation
"
    redefined to add some more stuff to the mcz archive:

    - package pragma to the source code.
    - stx subdirectory (optional), containing required support files for building
          plus resource files.
    - stx.bin subdirectory (optional), containing a precompiled binary dll as per architecture.
"
! !

!MCStxMczWriter methodsFor:'accessing'!

snapshotWriterClass
        ^ MCStxStWriter
! !

!MCStxMczWriter methodsFor:'visiting'!

writeBuildSupportFiles:aVersion for:aProjectDefinition
    aProjectDefinition forEachFileNameAndGeneratedContentsDo:[:file :contents |
        self addString: contents at: 'snapshot.stx/', file.
    ].
!

writeIndividualSourceFiles:aVersion for:aProjectDefinition
    "individual source files for dll compilation"

    aProjectDefinition classNames do:[:eachClassName |
        |cls fileName source|

        cls := Smalltalk classNamed:eachClassName.
        cls isNil ifTrue:[
            Transcript showCR:'class missing: ',eachClassName
        ] ifFalse:[
            cls autoload.

            fileName := (Smalltalk fileNameForClass:cls),'.st'.
            source := String streamContents:[:s | cls fileOutOn:s withTimeStamp:false].
            self addString: source at: 'snapshot.stx/', fileName.                               
        ]
    ].
!

writeResourceFiles:aVersion for:aProjectDefinition
    "language translations kept in externalfiles"

    |dir rsrcDir|

    dir := aProjectDefinition projectDirectory asFilename.
    (rsrcDir := dir / 'resources') exists ifTrue:[
        rsrcDir recursiveDirectoryContentsDo:[:relFn |
            (rsrcDir construct:relFn) isDirectory ifFalse:[
                self addString: ((rsrcDir construct:relFn) contentsOfEntireFile) at: 'snapshot.stx/resources/', relFn.
            ]            
        ].
    ].
!

writeSnapshot: aSnapshot
    self addString: (self serializeDefinitions: aSnapshot definitions) at: 'snapshot/source.', self snapshotWriterClass extension.
    "/ I whink, we can comment the following (or is it compatible?)
    self addString: (self serializeInBinary: aSnapshot) at: 'snapshot.bin'
!

writeVersion: aVersion
    |packageID prjDef|

    super writeVersion: aVersion.

    aVersion snapshot includeExtrasForSTX ifTrue:[
        "/ ST/X specific stuff here.

        packageID := aVersion package name.
        prjDef := ProjectDefinition definitionClassForPackage:packageID.
        prjDef isNil ifTrue:[
            "/ not a project definition mcz - simply skip
            Transcript show:'No projectDefinition for ',packageID, ' generated simple source only'.
        ] ifFalse:[
            "/ additional support files for recompilation...
            self writeIndividualSourceFiles: aVersion for: prjDef.
            self writeBuildSupportFiles: aVersion for: prjDef.
            self writeResourceFiles: aVersion for: prjDef.
        ]
    ]
! !

!MCStxMczWriter class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/goodies/monticello/MCStxMczWriter.st,v 1.2 2013-03-21 17:25:28 cg Exp $'
!

version_CVS
    ^ '$Header: /cvs/stx/stx/goodies/monticello/MCStxMczWriter.st,v 1.2 2013-03-21 17:25:28 cg Exp $'
! !

